@@ -17,15 +17,14 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_es.paginator import (
+from .literals import ESPartitionInstanceTypeType, LogTypeType
+from .paginator import (
     DescribeReservedElasticsearchInstanceOfferingsPaginator,
     DescribeReservedElasticsearchInstancesPaginator,
     GetUpgradeHistoryPaginator,
     ListElasticsearchInstanceTypesPaginator,
     ListElasticsearchVersionsPaginator,
 )
-
-from .literals import ESPartitionInstanceType, LogType
 from .type_defs import (
     AcceptInboundCrossClusterSearchConnectionResponseTypeDef,
     AdvancedSecurityOptionsInputTypeDef,
@@ -117,7 +116,7 @@ class Exceptions:
 
 class ElasticsearchServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -128,34 +127,34 @@ class ElasticsearchServiceClient:
         self, CrossClusterSearchConnectionId: str
     ) -> AcceptInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](./client.md#accept-inbound-cross-cluster-search-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#accept_inbound_cross_cluster_search_connection)
         """
 
     def add_tags(self, ARN: str, TagList: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.add_tags)
-        [Show boto3-stubs documentation](./client.md#add-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Show boto3-stubs documentation](./client.md#add_tags)
         """
 
     def associate_package(self, PackageID: str, DomainName: str) -> AssociatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.associate_package)
-        [Show boto3-stubs documentation](./client.md#associate-package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.associate_package)
+        [Show boto3-stubs documentation](./client.md#associate_package)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> CancelElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
-        [Show boto3-stubs documentation](./client.md#cancel-elasticsearch-service-software-update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Show boto3-stubs documentation](./client.md#cancel_elasticsearch_service_software_update)
         """
 
     def create_elasticsearch_domain(
@@ -171,15 +170,15 @@ class ElasticsearchServiceClient:
         EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = None,
         NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
         AdvancedOptions: Dict[str, str] = None,
-        LogPublishingOptions: Dict[LogType, "LogPublishingOptionTypeDef"] = None,
+        LogPublishingOptions: Dict[LogTypeType, "LogPublishingOptionTypeDef"] = None,
         DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
         AutoTuneOptions: AutoTuneOptionsInputTypeDef = None,
         TagList: List["TagTypeDef"] = None,
     ) -> CreateElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
-        [Show boto3-stubs documentation](./client.md#create-elasticsearch-domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#create_elasticsearch_domain)
         """
 
     def create_outbound_cross_cluster_search_connection(
@@ -189,8 +188,8 @@ class ElasticsearchServiceClient:
         ConnectionAlias: str,
     ) -> CreateOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](./client.md#create-outbound-cross-cluster-search-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#create_outbound_cross_cluster_search_connection)
         """
 
     def create_package(
@@ -201,103 +200,103 @@ class ElasticsearchServiceClient:
         PackageDescription: str = None,
     ) -> CreatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.create_package)
-        [Show boto3-stubs documentation](./client.md#create-package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.create_package)
+        [Show boto3-stubs documentation](./client.md#create_package)
         """
 
     def delete_elasticsearch_domain(
         self, DomainName: str
     ) -> DeleteElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
-        [Show boto3-stubs documentation](./client.md#delete-elasticsearch-domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#delete_elasticsearch_domain)
         """
 
     def delete_elasticsearch_service_role(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
-        [Show boto3-stubs documentation](./client.md#delete-elasticsearch-service-role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Show boto3-stubs documentation](./client.md#delete_elasticsearch_service_role)
         """
 
     def delete_inbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> DeleteInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](./client.md#delete-inbound-cross-cluster-search-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#delete_inbound_cross_cluster_search_connection)
         """
 
     def delete_outbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> DeleteOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](./client.md#delete-outbound-cross-cluster-search-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#delete_outbound_cross_cluster_search_connection)
         """
 
     def delete_package(self, PackageID: str) -> DeletePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_package)
-        [Show boto3-stubs documentation](./client.md#delete-package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.delete_package)
+        [Show boto3-stubs documentation](./client.md#delete_package)
         """
 
     def describe_domain_auto_tunes(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeDomainAutoTunesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
-        [Show boto3-stubs documentation](./client.md#describe-domain-auto-tunes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
+        [Show boto3-stubs documentation](./client.md#describe_domain_auto_tunes)
         """
 
     def describe_elasticsearch_domain(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
-        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#describe_elasticsearch_domain)
         """
 
     def describe_elasticsearch_domain_config(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
-        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-domain-config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Show boto3-stubs documentation](./client.md#describe_elasticsearch_domain_config)
         """
 
     def describe_elasticsearch_domains(
         self, DomainNames: List[str]
     ) -> DescribeElasticsearchDomainsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
-        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Show boto3-stubs documentation](./client.md#describe_elasticsearch_domains)
         """
 
     def describe_elasticsearch_instance_type_limits(
         self,
-        InstanceType: ESPartitionInstanceType,
+        InstanceType: ESPartitionInstanceTypeType,
         ElasticsearchVersion: str,
         DomainName: str = None,
     ) -> DescribeElasticsearchInstanceTypeLimitsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
-        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-instance-type-limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Show boto3-stubs documentation](./client.md#describe_elasticsearch_instance_type_limits)
         """
 
     def describe_inbound_cross_cluster_search_connections(
         self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeInboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
-        [Show boto3-stubs documentation](./client.md#describe-inbound-cross-cluster-search-connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
+        [Show boto3-stubs documentation](./client.md#describe_inbound_cross_cluster_search_connections)
         """
 
     def describe_outbound_cross_cluster_search_connections(
         self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
-        [Show boto3-stubs documentation](./client.md#describe-outbound-cross-cluster-search-connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
+        [Show boto3-stubs documentation](./client.md#describe_outbound_cross_cluster_search_connections)
         """
 
     def describe_packages(
@@ -307,8 +306,8 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribePackagesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_packages)
-        [Show boto3-stubs documentation](./client.md#describe-packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_packages)
+        [Show boto3-stubs documentation](./client.md#describe_packages)
         """
 
     def describe_reserved_elasticsearch_instance_offerings(
@@ -318,8 +317,8 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
-        [Show boto3-stubs documentation](./client.md#describe-reserved-elasticsearch-instance-offerings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Show boto3-stubs documentation](./client.md#describe_reserved_elasticsearch_instance_offerings)
         """
 
     def describe_reserved_elasticsearch_instances(
@@ -329,16 +328,16 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstancesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
-        [Show boto3-stubs documentation](./client.md#describe-reserved-elasticsearch-instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Show boto3-stubs documentation](./client.md#describe_reserved_elasticsearch_instances)
         """
 
     def dissociate_package(
         self, PackageID: str, DomainName: str
     ) -> DissociatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
-        [Show boto3-stubs documentation](./client.md#dissociate-package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
+        [Show boto3-stubs documentation](./client.md#dissociate_package)
         """
 
     def generate_presigned_url(
@@ -349,52 +348,52 @@ class ElasticsearchServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_compatible_elasticsearch_versions(
         self, DomainName: str = None
     ) -> GetCompatibleElasticsearchVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
-        [Show boto3-stubs documentation](./client.md#get-compatible-elasticsearch-versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Show boto3-stubs documentation](./client.md#get_compatible_elasticsearch_versions)
         """
 
     def get_package_version_history(
         self, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> GetPackageVersionHistoryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
-        [Show boto3-stubs documentation](./client.md#get-package-version-history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
+        [Show boto3-stubs documentation](./client.md#get_package_version_history)
         """
 
     def get_upgrade_history(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
-        [Show boto3-stubs documentation](./client.md#get-upgrade-history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Show boto3-stubs documentation](./client.md#get_upgrade_history)
         """
 
     def get_upgrade_status(self, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
-        [Show boto3-stubs documentation](./client.md#get-upgrade-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Show boto3-stubs documentation](./client.md#get_upgrade_status)
         """
 
     def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
-        [Show boto3-stubs documentation](./client.md#list-domain-names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Show boto3-stubs documentation](./client.md#list_domain_names)
         """
 
     def list_domains_for_package(
         self, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> ListDomainsForPackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
-        [Show boto3-stubs documentation](./client.md#list-domains-for-package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
+        [Show boto3-stubs documentation](./client.md#list_domains_for_package)
         """
 
     def list_elasticsearch_instance_types(
@@ -405,30 +404,30 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> ListElasticsearchInstanceTypesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
-        [Show boto3-stubs documentation](./client.md#list-elasticsearch-instance-types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Show boto3-stubs documentation](./client.md#list_elasticsearch_instance_types)
         """
 
     def list_elasticsearch_versions(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListElasticsearchVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
-        [Show boto3-stubs documentation](./client.md#list-elasticsearch-versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Show boto3-stubs documentation](./client.md#list_elasticsearch_versions)
         """
 
     def list_packages_for_domain(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListPackagesForDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
-        [Show boto3-stubs documentation](./client.md#list-packages-for-domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
+        [Show boto3-stubs documentation](./client.md#list_packages_for_domain)
         """
 
     def list_tags(self, ARN: str) -> ListTagsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_tags)
-        [Show boto3-stubs documentation](./client.md#list-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Show boto3-stubs documentation](./client.md#list_tags)
         """
 
     def purchase_reserved_elasticsearch_instance_offering(
@@ -438,30 +437,30 @@ class ElasticsearchServiceClient:
         InstanceCount: int = None,
     ) -> PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
-        [Show boto3-stubs documentation](./client.md#purchase-reserved-elasticsearch-instance-offering)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Show boto3-stubs documentation](./client.md#purchase_reserved_elasticsearch_instance_offering)
         """
 
     def reject_inbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> RejectInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](./client.md#reject-inbound-cross-cluster-search-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#reject_inbound_cross_cluster_search_connection)
         """
 
     def remove_tags(self, ARN: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.remove_tags)
-        [Show boto3-stubs documentation](./client.md#remove-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Show boto3-stubs documentation](./client.md#remove_tags)
         """
 
     def start_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> StartElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
-        [Show boto3-stubs documentation](./client.md#start-elasticsearch-service-software-update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Show boto3-stubs documentation](./client.md#start_elasticsearch_service_software_update)
         """
 
     def update_elasticsearch_domain_config(
@@ -474,7 +473,7 @@ class ElasticsearchServiceClient:
         CognitoOptions: "CognitoOptionsTypeDef" = None,
         AdvancedOptions: Dict[str, str] = None,
         AccessPolicies: str = None,
-        LogPublishingOptions: Dict[LogType, "LogPublishingOptionTypeDef"] = None,
+        LogPublishingOptions: Dict[LogTypeType, "LogPublishingOptionTypeDef"] = None,
         DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
         NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
@@ -482,8 +481,8 @@ class ElasticsearchServiceClient:
         AutoTuneOptions: "AutoTuneOptionsTypeDef" = None,
     ) -> UpdateElasticsearchDomainConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
-        [Show boto3-stubs documentation](./client.md#update-elasticsearch-domain-config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Show boto3-stubs documentation](./client.md#update_elasticsearch_domain_config)
         """
 
     def update_package(
@@ -494,16 +493,16 @@ class ElasticsearchServiceClient:
         CommitMessage: str = None,
     ) -> UpdatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.update_package)
-        [Show boto3-stubs documentation](./client.md#update-package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.update_package)
+        [Show boto3-stubs documentation](./client.md#update_package)
         """
 
     def upgrade_elasticsearch_domain(
         self, DomainName: str, TargetVersion: str, PerformCheckOnly: bool = None
     ) -> UpgradeElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
-        [Show boto3-stubs documentation](./client.md#upgrade-elasticsearch-domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#upgrade_elasticsearch_domain)
         """
 
     @overload
@@ -511,7 +510,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instance_offerings"]
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstanceofferingspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstanceofferingspaginator)
         """
 
     @overload
@@ -519,7 +518,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instances"]
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstancespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstancespaginator)
         """
 
     @overload
@@ -527,7 +526,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["get_upgrade_history"]
     ) -> GetUpgradeHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)[Show boto3-stubs documentation](./paginators.md#getupgradehistorypaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)[Show boto3-stubs documentation](./paginators.md#getupgradehistorypaginator)
         """
 
     @overload
@@ -535,7 +534,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_instance_types"]
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)[Show boto3-stubs documentation](./paginators.md#listelasticsearchinstancetypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)[Show boto3-stubs documentation](./paginators.md#listelasticsearchinstancetypespaginator)
         """
 
     @overload
@@ -543,5 +542,5 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_versions"]
     ) -> ListElasticsearchVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)[Show boto3-stubs documentation](./paginators.md#listelasticsearchversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)[Show boto3-stubs documentation](./paginators.md#listelasticsearchversionspaginator)
         """
