@@ -16,26 +16,26 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
-    AutoTuneDesiredState,
-    AutoTuneState,
-    DeploymentStatus,
-    DescribePackagesFilterName,
-    DomainPackageStatus,
-    ESPartitionInstanceType,
-    ESWarmPartitionInstanceType,
-    InboundCrossClusterSearchConnectionStatusCode,
-    LogType,
-    OptionState,
-    OutboundCrossClusterSearchConnectionStatusCode,
-    PackageStatus,
-    ReservedElasticsearchInstancePaymentOption,
-    RollbackOnDisable,
-    ScheduledAutoTuneActionType,
-    ScheduledAutoTuneSeverityType,
-    TLSSecurityPolicy,
-    UpgradeStatus,
-    UpgradeStep,
-    VolumeType,
+    AutoTuneDesiredStateType,
+    AutoTuneStateType,
+    DeploymentStatusType,
+    DescribePackagesFilterNameType,
+    DomainPackageStatusType,
+    ESPartitionInstanceTypeType,
+    ESWarmPartitionInstanceTypeType,
+    InboundCrossClusterSearchConnectionStatusCodeType,
+    LogTypeType,
+    OptionStateType,
+    OutboundCrossClusterSearchConnectionStatusCodeType,
+    PackageStatusType,
+    ReservedElasticsearchInstancePaymentOptionType,
+    RollbackOnDisableType,
+    ScheduledAutoTuneActionTypeType,
+    ScheduledAutoTuneSeverityTypeType,
+    TLSSecurityPolicyType,
+    UpgradeStatusType,
+    UpgradeStepType,
+    VolumeTypeType,
 )
 
 if sys.version_info >= (3, 8):
@@ -251,7 +251,7 @@ AutoTuneMaintenanceScheduleTypeDef = TypedDict(
 AutoTuneOptionsInputTypeDef = TypedDict(
     "AutoTuneOptionsInputTypeDef",
     {
-        "DesiredState": AutoTuneDesiredState,
+        "DesiredState": AutoTuneDesiredStateType,
         "MaintenanceSchedules": List["AutoTuneMaintenanceScheduleTypeDef"],
     },
     total=False,
@@ -260,7 +260,7 @@ AutoTuneOptionsInputTypeDef = TypedDict(
 AutoTuneOptionsOutputTypeDef = TypedDict(
     "AutoTuneOptionsOutputTypeDef",
     {
-        "State": AutoTuneState,
+        "State": AutoTuneStateType,
         "ErrorMessage": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -278,8 +278,8 @@ AutoTuneOptionsStatusTypeDef = TypedDict(
 AutoTuneOptionsTypeDef = TypedDict(
     "AutoTuneOptionsTypeDef",
     {
-        "DesiredState": AutoTuneDesiredState,
-        "RollbackOnDisable": RollbackOnDisable,
+        "DesiredState": AutoTuneDesiredStateType,
+        "RollbackOnDisable": RollbackOnDisableType,
         "MaintenanceSchedules": List["AutoTuneMaintenanceScheduleTypeDef"],
     },
     total=False,
@@ -290,7 +290,7 @@ _RequiredAutoTuneStatusTypeDef = TypedDict(
     {
         "CreationDate": datetime,
         "UpdateDate": datetime,
-        "State": AutoTuneState,
+        "State": AutoTuneStateType,
     },
 )
 _OptionalAutoTuneStatusTypeDef = TypedDict(
@@ -472,7 +472,7 @@ DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef = TypedDict(
 DescribePackagesFilterTypeDef = TypedDict(
     "DescribePackagesFilterTypeDef",
     {
-        "Name": DescribePackagesFilterName,
+        "Name": DescribePackagesFilterNameType,
         "Value": List[str],
     },
     total=False,
@@ -527,7 +527,7 @@ DomainEndpointOptionsTypeDef = TypedDict(
     "DomainEndpointOptionsTypeDef",
     {
         "EnforceHTTPS": bool,
-        "TLSSecurityPolicy": TLSSecurityPolicy,
+        "TLSSecurityPolicy": TLSSecurityPolicyType,
         "CustomEndpointEnabled": bool,
         "CustomEndpoint": str,
         "CustomEndpointCertificateArn": str,
@@ -573,7 +573,7 @@ DomainPackageDetailsTypeDef = TypedDict(
         "PackageType": Literal["TXT-DICTIONARY"],
         "LastUpdated": datetime,
         "DomainName": str,
-        "DomainPackageStatus": DomainPackageStatus,
+        "DomainPackageStatus": DomainPackageStatusType,
         "PackageVersion": str,
         "ReferencePath": str,
         "ErrorDetails": "ErrorDetailsTypeDef",
@@ -602,7 +602,7 @@ EBSOptionsTypeDef = TypedDict(
     "EBSOptionsTypeDef",
     {
         "EBSEnabled": bool,
-        "VolumeType": VolumeType,
+        "VolumeType": VolumeTypeType,
         "VolumeSize": int,
         "Iops": int,
     },
@@ -620,15 +620,15 @@ ElasticsearchClusterConfigStatusTypeDef = TypedDict(
 ElasticsearchClusterConfigTypeDef = TypedDict(
     "ElasticsearchClusterConfigTypeDef",
     {
-        "InstanceType": ESPartitionInstanceType,
+        "InstanceType": ESPartitionInstanceTypeType,
         "InstanceCount": int,
         "DedicatedMasterEnabled": bool,
         "ZoneAwarenessEnabled": bool,
         "ZoneAwarenessConfig": "ZoneAwarenessConfigTypeDef",
-        "DedicatedMasterType": ESPartitionInstanceType,
+        "DedicatedMasterType": ESPartitionInstanceTypeType,
         "DedicatedMasterCount": int,
         "WarmEnabled": bool,
-        "WarmType": ESWarmPartitionInstanceType,
+        "WarmType": ESWarmPartitionInstanceTypeType,
         "WarmCount": int,
     },
     total=False,
@@ -682,7 +682,7 @@ _OptionalElasticsearchDomainStatusTypeDef = TypedDict(
         "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
         "AdvancedOptions": Dict[str, str],
-        "LogPublishingOptions": Dict[LogType, "LogPublishingOptionTypeDef"],
+        "LogPublishingOptions": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
         "ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef",
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsTypeDef",
@@ -771,8 +771,8 @@ GetUpgradeHistoryResponseTypeDef = TypedDict(
 GetUpgradeStatusResponseTypeDef = TypedDict(
     "GetUpgradeStatusResponseTypeDef",
     {
-        "UpgradeStep": UpgradeStep,
-        "StepStatus": UpgradeStatus,
+        "UpgradeStep": UpgradeStepType,
+        "StepStatus": UpgradeStatusType,
         "UpgradeName": str,
     },
     total=False,
@@ -781,7 +781,7 @@ GetUpgradeStatusResponseTypeDef = TypedDict(
 InboundCrossClusterSearchConnectionStatusTypeDef = TypedDict(
     "InboundCrossClusterSearchConnectionStatusTypeDef",
     {
-        "StatusCode": InboundCrossClusterSearchConnectionStatusCode,
+        "StatusCode": InboundCrossClusterSearchConnectionStatusCodeType,
         "Message": str,
     },
     total=False,
@@ -845,7 +845,7 @@ ListDomainsForPackageResponseTypeDef = TypedDict(
 ListElasticsearchInstanceTypesResponseTypeDef = TypedDict(
     "ListElasticsearchInstanceTypesResponseTypeDef",
     {
-        "ElasticsearchInstanceTypes": List[ESPartitionInstanceType],
+        "ElasticsearchInstanceTypes": List[ESPartitionInstanceTypeType],
         "NextToken": str,
     },
     total=False,
@@ -889,7 +889,7 @@ LogPublishingOptionTypeDef = TypedDict(
 LogPublishingOptionsStatusTypeDef = TypedDict(
     "LogPublishingOptionsStatusTypeDef",
     {
-        "Options": Dict[LogType, "LogPublishingOptionTypeDef"],
+        "Options": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
         "Status": "OptionStatusTypeDef",
     },
     total=False,
@@ -926,7 +926,7 @@ _RequiredOptionStatusTypeDef = TypedDict(
     {
         "CreationDate": datetime,
         "UpdateDate": datetime,
-        "State": OptionState,
+        "State": OptionStateType,
     },
 )
 _OptionalOptionStatusTypeDef = TypedDict(
@@ -946,7 +946,7 @@ class OptionStatusTypeDef(_RequiredOptionStatusTypeDef, _OptionalOptionStatusTyp
 OutboundCrossClusterSearchConnectionStatusTypeDef = TypedDict(
     "OutboundCrossClusterSearchConnectionStatusTypeDef",
     {
-        "StatusCode": OutboundCrossClusterSearchConnectionStatusCode,
+        "StatusCode": OutboundCrossClusterSearchConnectionStatusCodeType,
         "Message": str,
     },
     total=False,
@@ -971,7 +971,7 @@ PackageDetailsTypeDef = TypedDict(
         "PackageName": str,
         "PackageType": Literal["TXT-DICTIONARY"],
         "PackageDescription": str,
-        "PackageStatus": PackageStatus,
+        "PackageStatus": PackageStatusType,
         "CreatedAt": datetime,
         "LastUpdatedAt": datetime,
         "AvailablePackageVersion": str,
@@ -1039,12 +1039,12 @@ ReservedElasticsearchInstanceOfferingTypeDef = TypedDict(
     "ReservedElasticsearchInstanceOfferingTypeDef",
     {
         "ReservedElasticsearchInstanceOfferingId": str,
-        "ElasticsearchInstanceType": ESPartitionInstanceType,
+        "ElasticsearchInstanceType": ESPartitionInstanceTypeType,
         "Duration": int,
         "FixedPrice": float,
         "UsagePrice": float,
         "CurrencyCode": str,
-        "PaymentOption": ReservedElasticsearchInstancePaymentOption,
+        "PaymentOption": ReservedElasticsearchInstancePaymentOptionType,
         "RecurringCharges": List["RecurringChargeTypeDef"],
     },
     total=False,
@@ -1056,7 +1056,7 @@ ReservedElasticsearchInstanceTypeDef = TypedDict(
         "ReservationName": str,
         "ReservedElasticsearchInstanceId": str,
         "ReservedElasticsearchInstanceOfferingId": str,
-        "ElasticsearchInstanceType": ESPartitionInstanceType,
+        "ElasticsearchInstanceType": ESPartitionInstanceTypeType,
         "StartTime": datetime,
         "Duration": int,
         "FixedPrice": float,
@@ -1064,7 +1064,7 @@ ReservedElasticsearchInstanceTypeDef = TypedDict(
         "CurrencyCode": str,
         "ElasticsearchInstanceCount": int,
         "State": str,
-        "PaymentOption": ReservedElasticsearchInstancePaymentOption,
+        "PaymentOption": ReservedElasticsearchInstancePaymentOptionType,
         "RecurringCharges": List["RecurringChargeTypeDef"],
     },
     total=False,
@@ -1119,9 +1119,9 @@ ScheduledAutoTuneDetailsTypeDef = TypedDict(
     "ScheduledAutoTuneDetailsTypeDef",
     {
         "Date": datetime,
-        "ActionType": ScheduledAutoTuneActionType,
+        "ActionType": ScheduledAutoTuneActionTypeType,
         "Action": str,
-        "Severity": ScheduledAutoTuneSeverityType,
+        "Severity": ScheduledAutoTuneSeverityTypeType,
     },
     total=False,
 )
@@ -1133,7 +1133,7 @@ ServiceSoftwareOptionsTypeDef = TypedDict(
         "NewVersion": str,
         "UpdateAvailable": bool,
         "Cancellable": bool,
-        "UpdateStatus": DeploymentStatus,
+        "UpdateStatus": DeploymentStatusType,
         "Description": str,
         "AutomatedUpdateDate": datetime,
         "OptionalDeployment": bool,
@@ -1222,7 +1222,7 @@ UpgradeHistoryTypeDef = TypedDict(
     {
         "UpgradeName": str,
         "StartTimestamp": datetime,
-        "UpgradeStatus": UpgradeStatus,
+        "UpgradeStatus": UpgradeStatusType,
         "StepsList": List["UpgradeStepItemTypeDef"],
     },
     total=False,
@@ -1231,8 +1231,8 @@ UpgradeHistoryTypeDef = TypedDict(
 UpgradeStepItemTypeDef = TypedDict(
     "UpgradeStepItemTypeDef",
     {
-        "UpgradeStep": UpgradeStep,
-        "UpgradeStepStatus": UpgradeStatus,
+        "UpgradeStep": UpgradeStepType,
+        "UpgradeStepStatus": UpgradeStatusType,
         "Issues": List[str],
         "ProgressPercent": float,
     },
